package ru.ulstu.project.controller;

import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import ru.ulstu.project.model.Project;
import ru.ulstu.project.model.ProjectDto;
import ru.ulstu.project.service.ProjectService;
import springfox.documentation.annotations.ApiIgnore;

import java.util.List;

@Controller()
@RequestMapping(value = "/projects")
@ApiIgnore
public class ProjectController {
    private final ProjectService projectService;

    public ProjectController(ProjectService projectService) {
        this.projectService = projectService;
    }

    @GetMapping("/dashboard")
    public void getDashboard(ModelMap modelMap) {
        modelMap.put("projects", projectService.findAllDto());
    }

    @GetMapping("/projects")
    public void getProjects(ModelMap modelMap) {
        modelMap.put("projects", projectService.findAllDto());
    }

    @GetMapping("/project")
    public void getProject(ModelMap modelMap, @RequestParam(value = "id") Integer id) {
        if (id != null && id > 0) {
            modelMap.put("projectDto", projectService.findOneDto(id));
        } else {
            modelMap.put("projectDto", new ProjectDto());
        }
    }

    @ModelAttribute("allStatuses")
    public List<Project.ProjectStatus> getProjectStatuses() {
        return projectService.getProjectStatuses();
    }
}
